@@ -15,5 +15,17 @@
  * OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */
 
-ALTER TABLE account
-  ADD COLUMN last_login_time timestamptz(3) NULL;
+ALTER TABLE account_picture
+  ADD COLUMN app_id uuid NULL,
+  ADD COLUMN submitter_account_id uuid NULL,
+  ADD COLUMN team_id uuid NULL;
+
+UPDATE account_picture
+  SET
+    submitter_account_id = account_id;
+
+ALTER TABLE account_picture
+  ALTER COLUMN submitter_account_id SET NOT NULL;
+
+DROP TRIGGER on_account_picture_updated
+  ON account;
